﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.IO;

namespace HtmlWpfRtf.Common {
    /// <summary>
    /// Interaktionslogik für FInsertHTMLTable.xaml
    /// </summary>
    public partial class WInsertHTMLTable : Window {
        public WInsertHTMLTable() {
            start = true;
            InitializeComponent();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e) {
            cbCellFrame.SelectedIndex = 0;
            start = false;
            createWebTable();
        }

        private StringBuilder sbTipp = new StringBuilder();

        private bool bRetCode = false;

        public bool Retcode {
            get { return bRetCode; }
        }

        private bool start = false;

        int countRows = 0;  // tCountRows
        int countCols = 0;

        public int AnzRow {
            get { return (int)countRows; }
        }
        public int AnzCol {
            get { return (int)countCols; }
        }


        public bool HeaderInFirstRow {
            get { return chkHeaderInFirstRow.IsChecked == true; }
        }

        public bool HeaderInFirstCol {
            get { return chkHeaderInFirstCol.IsChecked == true; }
        }


        public bool Head {
            get { return chkthead.IsChecked == true; }
        }
        public bool Body {
            get { return chktbody.IsChecked == true; }
        }
        public bool Foot {
            get { return chktfoot.IsChecked == true; }
        }


        public bool Colgroup {
            get { return chkColgroup.IsChecked == true; }
        }


        public bool CellSpacing {
            get { return chkCellSpacing.IsChecked == true; }
        }
        public bool CellPadding {
            get { return chkCellPadding.IsChecked == true; }
        }


        public int CellFrame {
            get { return cbCellFrame.SelectedIndex; }
        }





        private void Window_KeyDown(object sender, KeyEventArgs e) {
            if (Keyboard.IsKeyDown(Key.Return)) {
                bnOk_Click(sender, e);
            }
        }
        private void bnOk_Click(object sender, RoutedEventArgs e) {
            if (!int.TryParse(tCountRows.Text.Trim(), out countRows)) {
                Basis.ErrorMsg("Please insert a valid number", "Error");
                tCountRows.Focus();
                return;
            }
            if (countRows < 1) {
                Basis.ErrorMsg("Please insert a number greater zero", "Error");
                tCountRows.Focus();
                return;
            }

            if (!int.TryParse(tCountCols.Text.Trim(), out countCols)) {
                Basis.ErrorMsg("Please insert a valid number", "Error");
                tCountCols.Focus();
                return;
            }
            if (countCols < 1) {
                Basis.ErrorMsg("Please insert a number greater zero", "Error");
                tCountCols.Focus();
                return;
            }
            bRetCode = true;
            Close();
        }

        private void createWebTable() {
            if (start)
                return;
            if (!int.TryParse(tCountRows.Text.Trim(), out countRows)) {
                return;
            }
            if (countRows < 1) {
                return;
            }

            if (!int.TryParse(tCountCols.Text.Trim(), out countCols)) {
                return;
            }
            if (countCols < 1) {
                return;
            }
            sbTipp.Clear();

            StringBuilder sb = new StringBuilder();
            sb.AppendLine("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
            sb.AppendLine("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">");
            sb.AppendLine("<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">");
            sb.AppendLine("<head>");
            sb.AppendLine("<title> show table </title>");
            sb.AppendLine("<meta name=\"author\" content=\"Administrator\"/>");
            sb.AppendLine("<meta http-equiv=\"content-type\" content=\"text/html; charset=ISO-8859-1\"/>");
            sb.AppendLine("<style type=\"text/css\"  id=\"internalStyle\" >");

            if (CellFrame <= 2) {
                sb.AppendLine("  table {");
                sb.AppendLine("    border: 1px solid;");
                if (CellSpacing) {
                    sbTipp.AppendLine("Don't use \"border-collapse:collapse;\"");
                }
                else {
                    sb.AppendLine("    border-collapse:collapse;");
                }
                sb.AppendLine("  }");
                sb.AppendLine("  td, th {");
                sb.AppendLine("    border: 1px solid; ");
                sb.AppendLine("    border-color: black;");
                sb.AppendLine("  }");
            }
            else {
                sbTipp.AppendLine("Don't use \"table border\", \"th border\" and \"td border\"");
            }
            sb.AppendLine("  tfoot {");
            sb.AppendLine("    color: red;");
            sb.AppendLine("  }");
            sb.AppendLine("  thead {");
            sb.AppendLine("    color: blue;");
            sb.AppendLine("  }");
            sb.AppendLine("  tbody {");
            sb.AppendLine("    background-color: #EEEEEE;");
            sb.AppendLine("  }");
            sb.AppendLine("  th {");
            sb.AppendLine("    color: green;");
            sb.AppendLine("  }");
            sb.AppendLine("</style>");

            sb.AppendLine("</head>");
            sb.AppendLine("<body>");
            String table = Middleware.createTable(AnzRow, AnzCol, HeaderInFirstRow, HeaderInFirstCol,
                                Head, Body, Foot, CellSpacing, CellPadding, Colgroup, CellFrame);
            sb.AppendLine(table);
            sb.AppendLine("</body>");
            sb.AppendLine("</html>");
            String path = System.Environment.CurrentDirectory;
            if (!path.EndsWith("\\"))
                path += "\\";
            File.WriteAllText(path + "test.xhtml", sb.ToString().Replace(Konst.C_TAB, "\t"));
            browser.Navigate("file:///" + path + "test.xhtml");

            if (sbTipp.Length > 0) {
                bnTipp.IsEnabled = true;
                bnTipp.Foreground = Brushes.Red;
                bnTipp.FontWeight = FontWeights.Bold;
            }
            else {
                bnTipp.IsEnabled = false;
                bnTipp.Foreground = Brushes.Black;
                bnTipp.FontWeight = FontWeights.Normal;
            }

        }  // createWebTable

        private void bnCancel_Click(object sender, RoutedEventArgs e) {
            Close();
        }

        private void tCountRows_TextChanged(object sender, TextChangedEventArgs e) {
            createWebTable();
        }

        private void tCountCols_TextChanged(object sender, TextChangedEventArgs e) {
            createWebTable();
        }

        private void chkHeaderInFirstRow_Checked(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chkHeaderInFirstCol_Checked(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chkthead_Checked(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chktbody_Checked(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chktfoot_Checked(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chkColgroup_Checked(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chkCellSpacing_Checked(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chkCellPadding_Checked(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void cbCellFrame_SelectionChanged(object sender, SelectionChangedEventArgs e) {
            createWebTable();
        }

        private void chkCellSpacing_Click(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chkCellPadding_Click(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chkColgroup_Click(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chkHeaderInFirstRow_Click(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chkHeaderInFirstCol_Click(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chkthead_Click(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chktbody_Click(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void chktfoot_Click(object sender, RoutedEventArgs e) {
            createWebTable();
        }

        private void bnTipp_Click(object sender, RoutedEventArgs e) {
            Basis.Message(sbTipp.ToString(), "Tip for the CSS-File");
        }

    }
}
